@@ -212,6 +212,9 @@ sub launch_instance {
    if ($error) {
       print "\n\n   $error\n\n";sleep 3600; 
       Net::FullAuto::FA_Core::handle_error($error);
+   } elsif ($output=~/An error occurred/) {
+      print "\n\n   $output\n\n";sleep 3600;
+      Net::FullAuto::FA_Core::handle_error($output);
    }
    my $inst=$hash->{Instances}->[0];
    my $server_launch=<<'END';
